@@ -70,7 +70,8 @@ the xmlns.
   my $xml = "<userId _value_type='long'>$user_id</userId>";
 
   ###########
-  # IMPORTANT: you must set _value_type to long - matching the requirement of the SOAP server
+  # Warning: you might have to supply data types (using _value_type) 
+  # for each field, depending on the service you are talking to
   ###########
 
   # Actually do the call
@@ -134,8 +135,8 @@ the SOAP transport (e.g. web server error/could not connect etc)
 undef will be returned and the error() will be set.
 
 Each node in the XML supplied (either by string or from a filename)
-needs to have _value_type defined or the submitted format will
-default to 'string'.
+can have _value_type defined or the submitted format may
+default to 'string' (depending on SOAP::Data::Builder).
 
 You can supply 'filename' rather than 'xml' and it will read in from
 the file.
